#!/bin/bash

SIMUDIR=`pwd`

############################################################
# Parallelism
############################################################

veget=0
parallel=1
ntasks=2
nthreads=2
hostname=`hostname`

if [ $parallel = 1 ] ; then
   mpirun=mpirun
   if [ "${hostname:0:6}" = "ciclad" ] ; then mpirun=/usr/lib64/openmpi/1.6.5-gfortran/bin/mpirun ; fi
   exec="$mpirun  -np $ntasks gcm.e"
else
   exec=./gcm.e
fi



############################################################
# Dates control
############################################################

stopsim=200101
# Readin year and month in file 'etat'
year=`tail -1 etat | awk ' { print $1 } ' | cut -c1-4`
month=`tail -1 etat | awk ' { print $1 } ' | cut -c5-`
if [ $month = 12 ] ; then
  nextmonth=1
  nextyear=`expr $year + 1`
else
  nextmonth=`expr $month + 1`
  nextyear=$year
fi
if [ `echo $nextmonth | wc -m` = 2  ] ; then
   nextmonth=0$nextmonth
fi
dayref=$(( $(( 10#$month - 1 )) * 30 + 1 ))
ym=$year$month
next=$nextyear$nextmonth
echo ym $ym
echo mois ancien  : $ym
echo mois nouveau : $next

############################################################
# Preparing simulation on work directory
############################################################

WDIR=WD${ym}_$$
if [ -d $WDIR ] ; then echo $WDIR already exists ; exit ; fi

mkdir -p $WDIR
cp *.sh DEF/* $WDIR
cd $WDIR
sed -i'' -e 's/raz_date=.*.$/raz_date=1/' -e 's/dayref=.*.$/dayref='$dayref'/' run.def
for st in start startphy ; do ln -s ../$st.$ym.nc $st.nc ; done
if [ $veget = 1 ] ; then for f in stomate sechiba ; do ln -s ../start_${f}.$ym.nc ${f}_rest_in.nc ; done ; fi
for file in limit.nc gcm.e reb.sh ; do ln -s ../$file . ; done
if [ -d ../ecrad_data ] ; then ln -s ../ecrad_data ./ ; fi


echo '##################################################################'
echo    'Lancement de la simulation'
echo '##################################################################'

export OMP_STACKSIZE=800M  # Max stack size for open MP
export OMP_NUM_THREADS=$nthreads  # Number of openMP processes (threads)
ulimit -s unlimited        # Allowing illimted memory for ...
$exec > listing

if [ ! -f restartphy.nc ] ; then
echo PROBLEME PAS DE FICHIER RESTARTPHY
exit
fi

echo '##################################################################'
echo     'sauvegarde des fichiers de sortie'
echo '##################################################################'

PUT='cp -f'
# listing
${PUT} listing ${SIMUDIR}/list$ym

# restart(s)
${PUT} restart.nc ${SIMUDIR}/start.$next.nc
${PUT} restartphy.nc ${SIMUDIR}/startphy.$next.nc
if [ $veget = 1 ] ; then for f in stomate sechiba ; do ${PUT} ${f}_rest_out.nc ${SIMUDIR}/start_${f}.$next.nc ; done ; fi

# Rebuilding full globe files from sub-domains
chmod +x reb.sh
./reb.sh $ym $SIMUDIR
for file in histmth histday histhf  ; do
	${SIMUDIR}/reb.sh $file ; ${PUT} $file.nc ${SIMUDIR}/$file.$ym.nc ; done

echo '##################################################################'
echo     'preparation et lancement de la simulation suivante'
echo '##################################################################'

# Gestion du fichier etat de controle de la simulation
echo $ym OK >> $SIMUDIR/etat
echo $next a faire >> $SIMUDIR/etat
# ${PUT} etat $SIMUDIR/etat # Pas necessaire car etat est un lien vers $SIMUDIR/etat

# Arret si on est arrive au bout
if [ $next =  $stopsim ] ; then
   echo 'On arrive au bout, simulation next:'$next', stopsim:'$stopsim
   exit
fi


echo '##################################################################'
echo      'lancement de la simulation suivante tmp_'$simul' depuis :'
echo '##################################################################'
pwd


cd $SIMUDIR
./enchaine.sh &
